import argparse

from invoke import UnexpectedExit
from termcolor import colored

from .config import load_config
from .handlers import action_custom_command
from .server_session import enter_live_server
from .colored_print import colored_print
from .genete_example import generate_local_config


def main():
    parser = argparse.ArgumentParser(description="Project Commands")
    settings = load_config()
    choices = list(settings.commands.keys())
    choices.append('sv')
    choices.append('ex')
    parser.add_argument("command", choices=choices, help="Command to execute")
    args = parser.parse_args()
    if args.command == 'sv':
        enter_live_server(settings)
        return
    if args.command == 'ex':
        generate_local_config()
        return 
    handler = settings.commands.get(args.command, None)
    if handler:
        try:
            action_custom_command(handler, settings=settings)
        except UnexpectedExit:
            pass

    else:
        message = 'Command "{}" not found'.format(args.command)
        colored_message = colored(message, 'red', attrs=['bold'])
        print(colored_message)


if __name__ == '__main__':
    main()



import configparser
import os, sys

from .schemas import Tez, Server, Project
from .colored_print import colored_print



def load_config() -> Tez:
    try:
        config_file_name = ".tez"
        possible_locations = [
            os.path.join(os.getcwd(), config_file_name),
            # os.path.expanduser(f"~/{config_file_name}"),
            # os.path.join(os.path.dirname(os.path.abspath(__file__)), config_file_name)
        ]
    
        config_file = None
        for location in possible_locations:
            if os.path.exists(location):
                config_file = location
                break
    
        if not config_file:
            raise FileNotFoundError(
                f"Configuration file '{config_file_name}' not found in current directory, home directory, or script location.")
    
        config = configparser.ConfigParser()
        config.read(config_file)
    
    
        server_config = {
            "host": config.get("server", "SERVER_HOST", fallback=None),
            "user": config.get("server", "SERVER_USER", fallback=None),
            "password": config.get("server", "SERVER_PASSWORD", fallback=None),
            "port": config.getint("server", "SERVER_PORT", fallback=None),
        }
    
        commands = {}
        for command, terminal_command in config["commands"].items():
            commands[command] = terminal_command
    
        project_config = {
            "path": config.get("project", "PROJECT_PATH", fallback=None),
        }
    
        return Tez(
            server=Server(**server_config),
            commands=commands,
            project=Project(**project_config),
        )
    except:
        return Tez(server=Server(host=None, port=None, user=None, password=None), project=Project(path=None), commands={})




from termcolor import colored


def colored_print(msg, color):
    msg = msg.lstrip().strip()
    data = msg.split('\n')
    print(colored('_' * len(data[0]), 'yellow',  attrs=['bold']))
    print(colored(msg, color, attrs=['bold']))
    print('🏎\n\n')